package org.especialistajee.cw.filmoteca.domain;

import java.util.Date;
import java.util.List;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * La clase <code>PeliculaBean</code> se encarga de encapsular los datos de las peliculas.
 * @author malozano
 *
 */
@XmlRootElement(name="pelicula")
public class PeliculaBean {
	
	/**
	 * Identificador de la pelicula.
	 */
	int id;
	
	/**
	 * Titulo de la pelicula.
	 */
	String titulo;
	
	/**
	 * Lista de directores de la pelicula.
	 */
	String director;
	
	/**
	 * Lista de actores de la pelicula.
	 */
	List<ActorBean> actores;
	
	/**
	 * Fecha de estreno de la pelicula en su pais de origen.
	 */
	Date fechaEstreno;
	
	/**
	 * Duracion de la pelicula en minutos.
	 */
	int duracion;

	/**
	 * Enlaces en formato Atom
	 */
	List<LinkBean> links;
	
	/**
	 * Devuelve el titulo de la pelicula.
	 * @return Cadena con el titulo de la pelicula, o <code>null</code> si no tiene
	 * titulo asignado.
	 */
	@XmlAttribute(name="titulo")
	public String getTitulo() {
		return titulo;
	}
	/**
	 * Modifica el titulo de la pelicula.
	 * @param titulo Nuevo titulo que se le asignara a la pelicula.
	 */
	public void setTitulo(String titulo) {
		this.titulo = titulo;
	}
	/**
	 * Devuelve el director de la pelicula
	 * @return Director de la pelicula, o <code>null</code> si
	 * no tiene director asignado.
	 */
	@XmlAttribute(name="director")
	public String getDirector() {
		return director;
	}
	/**
	 * Modifica el director de la pelicula.
	 * @param directores Nuevo director que se asignara a la pelicula.
	 */
	public void setDirector(String director) {
		this.director = director;
	}
	/**
	 * Devuelve la lista de actores de la pelicula. A cada actor se le asocia el personaje
	 * que interpreta en la pelicula.
	 * @return Lista de actores de la pelicula, junto a sus personajes asociados, o <code>null</code> si no tiene
	 * actores asignados.
	 */
	@XmlElementWrapper(name="actores")
	@XmlElement(name="actor")
	public List<ActorBean> getActores() {
		return actores;
	}
	/**
	 * Modifica la lista de actores de la pelicula.
	 * @param actores Nueva lista de actores y personajes asociados que se le asignara a la pelicula.
	 */
	public void setActores(List<ActorBean> actores) {
		this.actores = actores;
	}
	/**
	 * Devuelve la fecha de estreno de la pelicula en su pais de origen.
	 * @return Fecha de estreno de la pelicula, o <code>null</code> si no tiene fecha
	 * de estreno asignada.
	 */
	@XmlAttribute(name="estreno")
	public Date getFechaEstreno() {
		return fechaEstreno;
	}
	/**
	 * Modifica la fecha de estreno de la pelicula
	 * @param fechaEstreno Nueva fecha de estreno que se le asignara a la pelicula.
	 */
	public void setFechaEstreno(Date fechaEstreno) {
		this.fechaEstreno = fechaEstreno;
	}
	/**
	 * Devuelve la duracion de la pelicula en minutos
	 * @return Numero de minutos que dura la pelicula
	 */
	@XmlAttribute(name="duracion")
	public int getDuracion() {
		return duracion;
	}
	/**
	 * Modifica la duracion de la pelicula.
	 * @param duracion Nuevo numero de minutos que se le asignara a la pelicula.
	 */
	public void setDuracion(int duracion) {
		this.duracion = duracion;
	}
	
	/**
	 * Devuelve el identificador de la pelicula.
	 * @return Codigo identificador de la pelicula.
	 */
	@XmlAttribute(name="id")
	public int getId() {
		return id;
	}
	
	/**
	 * Modifica el identificador de la pelicula.
	 * @param id Nuevo identificador que se le asignara a la pelicula.
	 */
	public void setId(int id) {
		this.id = id;
	}
	
	@XmlElement(name="link")
	public List<LinkBean> getLinks() {
		return links;
	}
	public void setLinks(List<LinkBean> links) {
		this.links = links;
	}	
	
	
}
