package org.especialistajee.cw.filmoteca.rest;

import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.core.UriInfo;

import org.especialistajee.cw.filmoteca.dao.DaoException;
import org.especialistajee.cw.filmoteca.dao.FactoriaDaos;
import org.especialistajee.cw.filmoteca.domain.LinkBean;
import org.especialistajee.cw.filmoteca.domain.PeliculaBean;

public class PeliculaResource {

	PeliculaBean pelicula;
	
	public PeliculaResource(int id) {
		try {
			this.pelicula = FactoriaDaos.getPeliculaDao().getPelicula(id);
			
			if(this.pelicula==null) {
				throw new WebApplicationException(Status.NOT_FOUND);
			}
		} catch (DaoException e) {
			throw new WebApplicationException(Status.INTERNAL_SERVER_ERROR);
		}		
	}
	
	@PUT
	@Consumes({MediaType.APPLICATION_JSON, MediaType.APPLICATION_XML})
	public Response updatePelicula(PeliculaBean pelicula) {
		try {
			pelicula.setId(this.pelicula.getId());
			FactoriaDaos.getPeliculaDao().updatePelicula(pelicula);
			return Response.noContent().build();
		} catch (DaoException e) {
			throw new WebApplicationException(Status.INTERNAL_SERVER_ERROR);
		}
	}
	
	@DELETE
	public Response delPelicula() {
		try {
			FactoriaDaos.getPeliculaDao().delPelicula(this.pelicula.getId());
			return Response.noContent().build();
		} catch (DaoException e) {
			throw new WebApplicationException(Status.INTERNAL_SERVER_ERROR);
		}		
	}

	@GET
	@Produces({MediaType.APPLICATION_JSON, MediaType.APPLICATION_XML})
	public PeliculaBean getPelicula(@Context UriInfo uriInfo) {
		try {
			this.pelicula.setActores(FactoriaDaos.getPeliculaDao().getActoresPelicula(this.pelicula.getId()).getActores());

			List<LinkBean> links = new ArrayList<LinkBean>();
			links.add(new LinkBean("self", uriInfo.getAbsolutePath().toString()));
			links.add(new LinkBean("pelicula/borrar", uriInfo.getAbsolutePath().toString()));
			links.add(new LinkBean("pelicula/modificar", uriInfo.getAbsolutePath().toString()));
			links.add(new LinkBean("pelicula/actores", uriInfo.getAbsolutePathBuilder().path("/actores").build().toString()));
			this.pelicula.setLinks(links);

			return pelicula;				
		} catch (DaoException e) {
			throw new WebApplicationException(Status.INTERNAL_SERVER_ERROR);
		}		
	}
	
	@Path("/actores")
	public ActoresResource getActores() {
		return new ActoresResource(this.pelicula.getId());
	}
}
