package org.especialistajee.cw.filmoteca.rest;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.Consumes;
import javax.ws.rs.DefaultValue;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.core.UriInfo;

import org.especialistajee.cw.filmoteca.dao.DaoException;
import org.especialistajee.cw.filmoteca.dao.FactoriaDaos;
import org.especialistajee.cw.filmoteca.domain.LinkBean;
import org.especialistajee.cw.filmoteca.domain.PeliculaBean;
import org.especialistajee.cw.filmoteca.domain.PeliculasBean;

@Path("/peliculas")
public class PeliculasResource {

	@Context 
	UriInfo uriInfo;
	
	@GET
	@Produces({MediaType.APPLICATION_JSON, MediaType.APPLICATION_XML})
	public PeliculasBean getPeliculas(@QueryParam("titulo") @DefaultValue("") String titulo) {
		try {
			PeliculasBean peliculas = null;
			
			if(titulo.isEmpty()) {
				peliculas = FactoriaDaos.getPeliculaDao().getPeliculas();
			} else {
				peliculas = FactoriaDaos.getPeliculaDao().getPeliculas(titulo);				
			}
			
			for(PeliculaBean pelicula: peliculas.getPeliculas()) {
				List<LinkBean> links = new ArrayList<LinkBean>();
				links.add(new LinkBean("self", uriInfo.getAbsolutePathBuilder().path("{id}").build(pelicula.getId()).toString()));
				pelicula.setLinks(links);
			}
			
			return peliculas;
		} catch (DaoException e) {
			throw new WebApplicationException(Status.INTERNAL_SERVER_ERROR);
		}		
	}

	@POST
	@Consumes({MediaType.APPLICATION_JSON, MediaType.APPLICATION_XML})
	public Response addPelicula(PeliculaBean pelicula, @Context UriInfo uriInfo) {
		try {
			int id = FactoriaDaos.getPeliculaDao().addPelicula(pelicula);
			
			URI uri = uriInfo.getAbsolutePathBuilder().path("{id}").build(id);
			return Response.created(uri).build();
			
		} catch (DaoException e) {
			e.printStackTrace();
			throw new WebApplicationException(Status.INTERNAL_SERVER_ERROR);
		}		
	}
	
	@Path("{id}")
	public PeliculaResource getPeliculaResource(@PathParam("id") int id) {
		return new PeliculaResource(id);
	}
}
